pytest-lamp
===========

.. image:: https://travis-ci.org/yunstanford/pytest-lamp.svg?branch=master
    :alt: build status
    :target: https://travis-ci.org/yunstanford/pytest-lamp

.. image:: https://coveralls.io/repos/github/yunstanford/pytest-lamp/badge.svg?branch=master
    :alt: coverage status
    :target: https://coveralls.io/github/yunstanford/pytest-lamp?branch=master


a Pytest Plugin.

Dev Mode.
